@@ -23,26 +23,19 @@ class ThreediApi:
     all named according to the pattern ``{resource}_{action}``, for example ``simulations_list``.
     Consult the docstrings of these methods for further information
 
-    ThreediApi requires a THREEDI_API_HOST and user credentials (THREEDI_API_USERNAME, THREEDI_API_PASSWORD). These can either be stored in
+    ThreediApi requires a THREEDI_API_HOST and user credentials.
+    These can either be stored in
     a ``.env`` file, supplied via environment variables, or passed as a config dictionary.
 
-    Alternatively, supply an THREEDI_API_ACCESS_TOKEN. If the THREEDI_API_ACCESS_TOKEN has expired, there are 3 methods
-    implemented for automatic token renewal:
-
-    - refresh token without client secret: supply a THREEDI_API_REFRESH_TOKEN
-    - refresh token with client secret: supply a THREEDI_API_REFRESH_TOKEN and THREEDI_API_CLIENT_SECRET
-    - client credentials flow: supply a THREEDI_API_CLIENT_SECRET
-
-    For personal api token authentication supply a THREEDI_API_PERSONAL_API_TOKEN.
-
-    For the client_credentials flow, direct usage of ``threedi_api_client.auth.refresh_oauth2_token``
-    is recommended to fetch the initial access token.
+    The preferred way of setting user credentials is using a "Personal API Key" in the
+    variable 'THREEDI_API_PERSONAL_API_TOKEN'. Using 'THREEDI_API_USERNAME'
+    and 'THREEDI_API_PASSWORD' to authenticate is also supported, but considered legacy. Consider upgrading
+    to personal API keys if you are using this form of authentication.
 
     1) A sample ``.env`` file could look like this::
 
         THREEDI_API_HOST=https://api.3di.live
-        THREEDI_API_USERNAME=your.username
-        THREEDI_API_PASSWORD=your.password
+        THREEDI_API_PERSONAL_API_TOKEN=lHtKAuCV.secret123
 
     This is used in your script as follows:
 
@@ -58,14 +51,12 @@ class ThreediApi:
     that you use to run the python interpreter with. On Windows::
 
         set THREEDI_API_HOST "https://api.3di.live"
-        set THREEDI_API_USERNAME "your.username"
-        set THREEDI_API_PASSWORD "your.password"
+        set THREEDI_API_PERSONAL_API_TOKEN "lHtKAuCV.secret123"
 
     On Linux or OSX::
 
         export THREEDI_API_HOST=https://api.3di.live
-        export THREEDI_API_USERNAME=your.username
-        export THREEDI_API_PASSWORD=your.password
+        export THREEDI_API_PERSONAL_API_TOKEN=lHtKAuCV.secret123
 
     3) The ``config`` keyword argument can be used like:
 
@@ -76,8 +67,7 @@ class ThreediApi:
 
         config = {
             "THREEDI_API_HOST": "https://api.3di.live",
-            "THREEDI_API_USERNAME": "your.username",
-            "THREEDI_API_PASSWORD": getpass(),
+            "THREEDI_API_PERSONAL_API_TOKEN": getpass(),
         }
 
         with ThreediApi(config=config) as api:
@@ -97,6 +87,14 @@ class ThreediApi:
         generator. The autogenerated code lives under ``threedi_api_client.openapi``.
 
     Notes:
+        **OAuth2**
+        For using OAuth2, supply an THREEDI_API_ACCESS_TOKEN. If the THREEDI_API_ACCESS_TOKEN has expired,
+        there are 3 methods implemented for automatic token renewal:
+
+        - refresh token without client secret: supply a THREEDI_API_REFRESH_TOKEN
+        - refresh token with client secret: supply a THREEDI_API_REFRESH_TOKEN and THREEDI_API_CLIENT_SECRET
+        - client credentials flow: supply a THREEDI_API_CLIENT_SECRET
+
         **Timeouts**
 
         A request without a timeout may block your python script indefinitely. It is always
